summaryrefslogtreecommitdiff
path: root/source4/torture/raw/open.c
diff options
context:
space:
mode:
Diffstat (limited to 'source4/torture/raw/open.c')
-rw-r--r--source4/torture/raw/open.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source4/torture/raw/open.c b/source4/torture/raw/open.c
index 21cc32eb09..145651b41d 100644
--- a/source4/torture/raw/open.c
+++ b/source4/torture/raw/open.c
@@ -1703,7 +1703,7 @@ static bool test_chained_ntcreatex_readx(struct torture_context *tctx, struct sm
torture_assert(tctx, torture_setup_dir(cli, BASEDIR), "Failed to setup up test directory: " BASEDIR);
torture_comment(tctx, "Checking RAW_NTCREATEX_READX chained on "
- "non-existant file \n");
+ "non-existent file \n");
/* ntcreatex parameters */
io.generic.level = RAW_OPEN_NTCREATEX_READX;
@@ -1727,7 +1727,7 @@ static bool test_chained_ntcreatex_readx(struct torture_context *tctx, struct sm
io.ntcreatexreadx.in.remaining = 0;
io.ntcreatexreadx.out.data = (uint8_t *)buf2;
/* try to open the non-existant file */
status = smb_raw_open(cli->tree, mem_ctx, &io);
CHECK_STATUS(status, NT_STATUS_OBJECT_NAME_NOT_FOUND);
fnum = io.ntcreatexreadx.out.file.fnum;
@@ -1727,7 +1727,7 @@ static bool test_chained_ntcreatex_readx(struct torture_context *tctx, struct sm
io.ntcreatexreadx.in.remaining = 0;
io.ntcreatexreadx.out.data = (uint8_t *)buf2;
- /* try to open the non-existant file */
+ /* try to open the non-existent file */
status = smb_raw_open(cli->tree, mem_ctx, &io);
CHECK_STATUS(status, NT_STATUS_OBJECT_NAME_NOT_FOUND);